# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_trade_condition_statistics.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRsystemathics/apis/services/tick_analytics/v1/tick_trade_condition_statistics.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xc4\x01\n#TickTradeConditionStatisticsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\"\xf0\x01\n$TickTradeConditionStatisticsResponse\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x14\n\x05\x63ount\x18\x02 \x01(\x03R\x05\x63ount\x12\x14\n\x05total\x18\x03 \x01(\x03R\x05total\x12\x1e\n\npercentage\x18\x04 \x01(\x01R\npercentage\x12\x16\n\x06volume\x18\x05 \x01(\x03R\x06volume\x12!\n\x0ctotal_volume\x18\x06 \x01(\x03R\x0btotalVolume\x12+\n\x11volume_percentage\x18\x07 \x01(\x01R\x10volumePercentage2\xa6\x02\n#TickTradeConditionStatisticsService\x12\xfe\x01\n\x1cTickTradeConditionStatistics\x12Q.systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsRequest\x1aR.systemathics.apis.services.tick_analytics.v1.TickTradeConditionStatisticsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/v1/tick-analytics/trade-condition-statistics0\x01\x42\xa6\x02\n0com.systemathics.apis.services.tick_analytics.v1B!TickTradeConditionStatisticsProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_trade_condition_statistics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B!TickTradeConditionStatisticsProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKTRADECONDITIONSTATISTICSSERVICE'].methods_by_name['TickTradeConditionStatistics']._loaded_options = None
  _globals['_TICKTRADECONDITIONSTATISTICSSERVICE'].methods_by_name['TickTradeConditionStatistics']._serialized_options = b'\202\323\344\223\002/\022-/v1/tick-analytics/trade-condition-statistics'
  _globals['_TICKTRADECONDITIONSTATISTICSREQUEST']._serialized_start=266
  _globals['_TICKTRADECONDITIONSTATISTICSREQUEST']._serialized_end=462
  _globals['_TICKTRADECONDITIONSTATISTICSRESPONSE']._serialized_start=465
  _globals['_TICKTRADECONDITIONSTATISTICSRESPONSE']._serialized_end=705
  _globals['_TICKTRADECONDITIONSTATISTICSSERVICE']._serialized_start=708
  _globals['_TICKTRADECONDITIONSTATISTICSSERVICE']._serialized_end=1002
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from systemathics.apis.services.calendar.v1 import calendar_pb2 as systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2


class CalendarServiceStub(object):
    """Called to request screener data.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HolidayCurrencies = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/HolidayCurrencies',
                request_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCurrenciesRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCurrenciesResponse.FromString,
                )
        self.HolidayCenter = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/HolidayCenter',
                request_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCenterRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCenterResponse.FromString,
                )
        self.Holidays = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/Holidays',
                request_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysResponse.FromString,
                )
        self.TradingHoursMic = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/TradingHoursMic',
                request_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicResponse.FromString,
                )
        self.TradingHours = channel.unary_unary(
                '/systemathics.apis.services.calendar.v1.CalendarService/TradingHours',
                request_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursResponse.FromString,
                )


class CalendarServiceServicer(object):
    """Called to request screener data.
    """

    def HolidayCurrencies(self, request, context):
        """Gets currencies with holidays information 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HolidayCenter(self, request, context):
        """Gets currencies with holidays information 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Holidays(self, request, context):
        """Gets currencies with holidays information 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TradingHoursMic(self, request, context):
        """Gets mic code with trading hours information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TradingHours(self, request, context):
        """Gets mic code with trading hours information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CalendarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HolidayCurrencies': grpc.unary_unary_rpc_method_handler(
                    servicer.HolidayCurrencies,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCurrenciesRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCurrenciesResponse.SerializeToString,
            ),
            'HolidayCenter': grpc.unary_unary_rpc_method_handler(
                    servicer.HolidayCenter,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCenterRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCenterResponse.SerializeToString,
            ),
            'Holidays': grpc.unary_unary_rpc_method_handler(
                    servicer.Holidays,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysResponse.SerializeToString,
            ),
            'TradingHoursMic': grpc.unary_unary_rpc_method_handler(
                    servicer.TradingHoursMic,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicResponse.SerializeToString,
            ),
            'TradingHours': grpc.unary_unary_rpc_method_handler(
                    servicer.TradingHours,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.calendar.v1.CalendarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CalendarService(object):
    """Called to request screener data.
    """

    @staticmethod
    def HolidayCurrencies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/HolidayCurrencies',
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCurrenciesRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCurrenciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HolidayCenter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/HolidayCenter',
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCenterRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidayCenterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Holidays(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/Holidays',
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.HolidaysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TradingHoursMic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/TradingHoursMic',
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursMicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TradingHours(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.calendar.v1.CalendarService/TradingHours',
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_calendar_dot_v1_dot_calendar__pb2.TradingHoursResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_greeks.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6systemathics/apis/services/daily/v1/daily_greeks.proto\x12#systemathics.apis.services.daily.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xb7\x01\n\x12\x44\x61ilyGreeksRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"[\n\x13\x44\x61ilyGreeksResponse\x12\x44\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.daily.v1.DailyGreeksR\x04\x64\x61ta\"\xb2\x01\n\x0b\x44\x61ilyGreeks\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x14\n\x05\x64\x65lta\x18\x02 \x01(\x01R\x05\x64\x65lta\x12\x14\n\x05gamma\x18\x03 \x01(\x01R\x05gamma\x12\x14\n\x05theta\x18\x04 \x01(\x01R\x05theta\x12\x12\n\x04vega\x18\x05 \x01(\x01R\x04vega\x12\x10\n\x03rho\x18\x06 \x01(\x01R\x03rho\x12\x14\n\x05score\x18\x07 \x01(\x01R\x05score2\xb1\x01\n\x12\x44\x61ilyGreeksService\x12\x9a\x01\n\x0b\x44\x61ilyGreeks\x12\x37.systemathics.apis.services.daily.v1.DailyGreeksRequest\x1a\x38.systemathics.apis.services.daily.v1.DailyGreeksResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/daily/greeksB\xec\x01\n\'com.systemathics.apis.services.daily.v1B\x10\x44\x61ilyGreeksProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V1\xca\x02#Systemathics\\Apis\\Services\\Daily\\V1\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v1.daily_greeks_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v1B\020DailyGreeksProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V1\312\002#Systemathics\\Apis\\Services\\Daily\\V1\342\002/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V1'
  _globals['_DAILYGREEKSSERVICE'].methods_by_name['DailyGreeks']._options = None
  _globals['_DAILYGREEKSSERVICE'].methods_by_name['DailyGreeks']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/daily/greeks'
  _globals['_DAILYGREEKSREQUEST']._serialized_start=255
  _globals['_DAILYGREEKSREQUEST']._serialized_end=438
  _globals['_DAILYGREEKSRESPONSE']._serialized_start=440
  _globals['_DAILYGREEKSRESPONSE']._serialized_end=531
  _globals['_DAILYGREEKS']._serialized_start=534
  _globals['_DAILYGREEKS']._serialized_end=712
  _globals['_DAILYGREEKSSERVICE']._serialized_start=715
  _globals['_DAILYGREEKSSERVICE']._serialized_end=892
# @@protoc_insertion_point(module_scope)
